package Acme::PriPara::MainMembers::MinamiMirei;
use Mouse;
extends 'Acme::PriPara::MainMembers';
use utf8;

no Mouse;

1;

__DATA__

@@ MinamiMirei
firstname: みれぃ
lastname: 南
age: 13
birthday: 10/1
blood_type: A
cv: 芹澤優
costume_brand: Candy à la Mode
color: ライトブルー
