package Acme::PriPara::MainMembers::ManakaLaara;
use Mouse;
extends 'Acme::PriPara::MainMembers';
use utf8;

no Mouse;

1;

__DATA__

@@ ManakaLaara
firstname: らぁら
lastname: 真中
age: 10
birthday: 11/20
blood_type: O
cv: 茜屋日海夏
say: かしこま！
costume_brand: Twinkle Ribbon
color: ピンク
