package Acme::PriPara::MainMembers::TodoSion;
use Mouse;
extends 'Acme::PriPara::MainMembers';
use utf8;

no Mouse;

1;

__DATA__

@@ TodoSion
firstname: シオン
lastname: 東堂
age: 13
birthday: 1/5
blood_type: B
cv: 山北早紀
costume_brand: Baby Monster
color: グリーン
