use strict;
use Test::More 0.98;

use_ok $_ for qw(
    Acme::PriPara
    Acme::PriPara::MainMembers
    Acme::PriPara::MainMembers::DorothyWest
    Acme::PriPara::MainMembers::HojoSophy
    Acme::PriPara::MainMembers::ManakaLaara
    Acme::PriPara::MainMembers::MinamiMirei
    Acme::PriPara::MainMembers::ReonaWest
    Acme::PriPara::MainMembers::TodoSion
);

done_testing;

